==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm/test/com/openexchange/usm/test/AllUSMTests.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.test;

import junit.framework.*;

import com.openexchange.usm.contenttypes.calendar.impl.AllAppointmentsTestSuite;
import com.openexchange.usm.contenttypes.contacts.impl.AllContactsTestSuite;
import com.openexchange.usm.contenttypes.folder.impl.AllFoldersTestSuite;
import com.openexchange.usm.contenttypes.mail.impl.AllMailsTestSuite;
import com.openexchange.usm.contenttypes.manager.impl.AllContentTypeManagerTestSuite;
import com.openexchange.usm.contenttypes.tasks.impl.AllTasksTestSuite;
import com.openexchange.usm.contenttypes.test.ContentTypeTransferHandlerTest;
import com.openexchange.usm.mapping.impl.AllMappingsTestSuite;
import com.openexchange.usm.session.dataobject.AllSimpleDataObjectsTestSuite;
import com.openexchange.usm.session.impl.AllSessionTestSuite;
import com.openexchange.usm.session.sync.test.AllSessionSyncsTestSuite;

public class AllUSMTests extends TestSuite {
	private static class ResetCounter implements Test {
		public int countTestCases() {
			return 1;
		}

		public void run(TestResult arg0) {
			ContentTypeTransferHandlerTest.counter = 0;
		}
	}

	private final static ResetCounter RESETTER = new ResetCounter();

	public static Test suite() {
		TestSuite suite = new TestSuite("All USM junit tests");
		suite.addTest(AllAppointmentsTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllContactsTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllFoldersTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllMailsTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllTasksTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllContentTypeManagerTestSuite.suite());
		suite.addTest(AllSimpleDataObjectsTestSuite.suite());
		suite.addTest(AllSessionTestSuite.suite());
		suite.addTest(AllSessionSyncsTestSuite.suite());
		suite.addTest(AllMappingsTestSuite.suite());
		return suite;
	}
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm/test/com/openexchange/usm/test/AllUSMTests.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.test;

import junit.framework.*;

import com.openexchange.usm.contenttypes.calendar.impl.AllAppointmentsTestSuite;
import com.openexchange.usm.contenttypes.contacts.impl.AllContactsTestSuite;
import com.openexchange.usm.contenttypes.folder.impl.AllFoldersTestSuite;
import com.openexchange.usm.contenttypes.mail.impl.AllMailsTestSuite;
import com.openexchange.usm.contenttypes.manager.impl.AllContentTypeManagerTestSuite;
import com.openexchange.usm.contenttypes.tasks.impl.AllTasksTestSuite;
import com.openexchange.usm.contenttypes.test.ContentTypeTransferHandlerTest;
import com.openexchange.usm.mapping.impl.AllMappingsTestSuite;
import com.openexchange.usm.session.dataobject.AllSimpleDataObjectsTestSuite;
import com.openexchange.usm.session.impl.AllSessionTestSuite;
import com.openexchange.usm.session.sync.test.AllSessionSyncsTestSuite;

public class AllUSMTests extends TestSuite {
	private static class ResetCounter implements Test {
		public int countTestCases() {
			return 1;
		}

		public void run(TestResult arg0) {
			ContentTypeTransferHandlerTest.counter = 0;
		}
	}

	private static final ResetCounter RESETTER = new ResetCounter();

	public static Test suite() {
		TestSuite suite = new TestSuite("All USM junit tests");
		suite.addTest(AllAppointmentsTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllContactsTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllFoldersTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllMailsTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllTasksTestSuite.suite());
		suite.addTest(RESETTER);
		suite.addTest(AllContentTypeManagerTestSuite.suite());
		suite.addTest(AllSimpleDataObjectsTestSuite.suite());
		suite.addTest(AllSessionTestSuite.suite());
		suite.addTest(AllSessionSyncsTestSuite.suite());
		suite.addTest(AllMappingsTestSuite.suite());
		return suite;
	}
}
